# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["PredictionRunResponse"]


class PredictionRunResponse(BaseModel):
    id: str
    """Unique prediction identifier"""

    error: Optional[str] = None
    """Error message if prediction failed to start"""
